Module: Novu::Api::Changes

Included in:
Client
Defined in:
lib/novu/api/changes.rb

Overview

Module Novu::Api::Changes provides an API for managing changes in the Novu application.

This module includes methods for retrieving, count, and applying bulk changes.

For more information on the Novu API(https://api.novu.co/api#/Changes), see https://docs.novu.co/api/get-changes/.

Instance Method Summary collapse

Instance Method Details

#apply_bulk_changes(changeIds) ⇒ Hash, number

Apply Bulk Change



41
42
43
# File 'lib/novu/api/changes.rb', line 41

def apply_bulk_changes(changeIds)
  post("/changes/bulk/apply", body: changeIds)
end

#apply_change(change_id) ⇒ Hash, number

Apply change

@pathparams:



53
54
55
# File 'lib/novu/api/changes.rb', line 53

def apply_change(change_id)
  post("/changes/#{change_id}/apply")
end

#changes(query = {}) ⇒ Hash, number

Returns a list of changes that can be paginated using the page query parameter

@queryparams:



21
22
23
# File 'lib/novu/api/changes.rb', line 21

def changes(query = {})
  get("/changes", query: query)
end

#count_changesHash, number

Returns changes count



30
31
32
# File 'lib/novu/api/changes.rb', line 30

def count_changes
  get("/changes/count")
end